@@ -3,68 +3,87 @@
  * Copyright (c) 1985-1988 by Supoj Sutanthavibul
  * Parts Copyright (c) 1989-2015 by Brian V. Smith
  * Parts Copyright (c) 1991 by Paul King
- * Parts Copyright (c) 2016-2018 by Thomas Loimer
+ * Parts Copyright (c) 2016-2020 by Thomas Loimer
  *
  * Any party obtaining a copy of these files is granted, free of charge, a
  * full and unrestricted irrevocable, world-wide, paid up, royalty-free,
  * nonexclusive right and license to deal in this software and documentation
  * files (the "Software"), including without limitation the rights to use,
- * copy, modify, merge, publish distribute, sublicense and/or sell copies of
+ * copy, modify, merge, publish, distribute, sublicense and/or sell copies of
  * the Software, and to permit persons who receive copies from any such
  * party to do so, with the only requirement being that the above copyright
  * and this permission notice remain intact.
  *
  */
 
-#include "fig.h"
-#include "figx.h"
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+#include "f_read.h"
+
+#include <ctype.h>		/* isdigit() */
+#include <errno.h>
+#include <limits.h>		/* PATH_MAX */
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+#ifdef I18N
+#include <locale.h>
+#endif
+
 #include "resources.h"
 #include "object.h"
 #include "mode.h"
-#include "f_read.h"
-#include "u_fonts.h"
+
+#include "d_spline.h"
+#include "e_update.h"
+#include "f_picobj.h"
+#include "f_util.h"
+#include "u_bound.h"
 #include "u_create.h"
-#include "w_drawprim.h"
-#include "w_export.h"
-#include "w_file.h"
-#include "w_print.h"
-#include "w_indpanel.h"
+#include "u_fonts.h"
+#include "u_free.h"
+#include "u_scale.h"
+#include "u_translate.h"
+#include "w_canvas.h"
 #include "w_color.h"
+#include "w_drawprim.h"
+#include "w_file.h"
+#include "w_layers.h"
 #include "w_msgpanel.h"
 #include "w_setup.h"
 #include "w_util.h"
 #include "w_zoom.h"
 
-#include "d_spline.h"
-#include "e_update.h"
-#include "f_picobj.h"
-#include "f_readold.h"
-#include "f_util.h"
-#include "u_bound.h"
-#include "u_free.h"
-#include "u_scale.h"
-#include "u_translate.h"
-#include "w_util.h"
-#include "w_layers.h"
+#include "xfig_math.h"
+
+extern int	read_1_3_objects(FILE *fp, char *buf, F_compound *obj,
+				int *resolution);	/* f_readold.c */
 
 /* EXPORTS */
 
-int		 defer_update_layers = 0; /* if != 0, update_layers() doesn't update */
-int		 line_no, save_line;	/* current input line number */
-int		 num_object;		/* current number of objects */
-char		*read_file_name;	/* current input file name */
+int	defer_update_layers = 0; /* if != 0, update_layers() doesn't update */
+void	fix_angle (float *angle);
+int	line_no, save_line;	/* current input line number */
+int	num_object;		/* current number of objects */
+char	*read_file_name;	/* current input file name */
+void	swap_colors (void);
 
 /* LOCAL */
 
 static char	Err_incomp[] = "Incomplete %s object at line %d.";
 
-static void        read_colordef(FILE *fp);
+static void        read_colordef(void);
 static F_ellipse  *read_ellipseobject(void);
 static F_line     *read_lineobject(FILE *fp);
 static F_text     *read_textobject(FILE *fp);
 static F_spline   *read_splineobject(FILE *fp);
 static F_arc      *read_arcobject(FILE *fp);
 static F_compound *read_compoundobject(FILE *fp);
+static int	  save_comment(void);
 static char	  *attach_comments(void);
 static void	   count_lines_correctly(FILE *fp);
 static int	   read_return(int status);
@@ -82,39 +101,38 @@ static Boolean	   contains_picture(F_compound *compound);
 /* input buffer length */
 #define	BUF_SIZE	1024
 
-char		 buf[BUF_SIZE];		/* input buffer */
-char		*comments[MAXCOMMENTS];	/* comments saved for current object */
-int		 numcom;		/* current comment index */
-Boolean		 com_alloc = False;	/* whether or not the comment array has been init. */
-int		 TFX;			/* true for 1.4TFX protocol */
-int		 proto;			/* file protocol*10 */
-float	         fproto, xfigproto;	/* floating values for protocol of figure
-					   file and current protocol */
+static char	buf[BUF_SIZE];		/* input buffer */
+static char	*comments[MAXCOMMENTS];	/* comments saved for current object */
+static int	numcom;			/* current comment index */
+static Boolean	com_alloc = False;	/* whether or not the comment array
+					   has been initialized */
+static int	TFX;			/* true for 1.4TFX protocol */
+static int	proto;			/* file protocol*10 */
+static float	fproto, xfigproto;	/* floating values for protocol of
+					   figure file and current protocol */
 
 /* initialize the user color counter - then read figure file.
    Called from load_file(), merge_file(), preview_figure(), load_lib_obj(),
    and paste(), but NOT from read_figure() (import Fig as picture) */
 
-
-void merge_colors (F_compound *objects);
-void swap_colors (void);
-int readfp_fig (FILE *fp, F_compound *obj, Boolean merge, int xoff, int yoff, fig_settings *settings);
-int read_line (FILE *fp);
-int read_objects (FILE *fp, F_compound *obj, int *res);
-void scale_figure (F_compound *obj, float mul, int offset);
-void shift_figure (F_compound *obj);
-void fix_depth (int *depth);
-void check_color (int *color);
-void convert_arrow (int *type, float *wd, float *ht);
-void fix_angle (float *angle);
-void skip_line (FILE *fp);
-int backslash_count (char *cp, int start);
-int save_comment (FILE *fp);
-void renumber_comp (F_compound *compound);
-void renumber (int *color);
+static void	merge_colors (F_compound *objects);
+static int	readfp_fig (FILE *fp, F_compound *obj, Boolean merge, int xoff,
+				int yoff, fig_settings *settings);
+static int	read_line (FILE *fp);
+static int	read_objects (FILE *fp, F_compound *obj, int *res);
+static void	scale_figure (F_compound *obj, float mul, int offset);
+static void	shift_figure (F_compound *obj);
+static void	fix_depth (int *depth);
+static void	check_color (int *color);
+static void	convert_arrow (int *type, float *wd, float *ht);
+static void	skip_line (FILE *fp);
+static int	backslash_count (char *cp, int start);
+static void	renumber_comp (F_compound *compound);
+static void	renumber (int *color);
 
 int
-read_figc(char *file_name, F_compound *obj, Boolean merge, Boolean remapimages, int xoff, int yoff, fig_settings *settings)
+read_figc(char *file_name, F_compound *obj, Boolean merge, Boolean remapimages,
+		int xoff, int yoff, fig_settings *settings)
 {
     int i,status;
 
@@ -223,7 +241,7 @@ read_fig(char *file_name, F_compound *obj, Boolean merge, int xoff, int yoff, fi
     }
 }
 
-int
+static int
 readfp_fig(FILE *fp, F_compound *obj, Boolean merge, int xoff, int yoff, fig_settings *settings)
 {
     int		    status;
@@ -231,7 +249,7 @@ readfp_fig(FILE *fp, F_compound *obj, Boolean merge, int xoff, int yoff, fig_set
     int		    resolution;
     char	    versstring[10];
 
-    defer_update_layers = 1;		/* prevent update_layers() from updating */
+    defer_update_layers = 1;	/* prevent update_layers() from updating */
 
     /* initialize settings structure in case we read an older Fig format */
     settings->landscape = appres.landscape;
@@ -250,7 +268,7 @@ readfp_fig(FILE *fp, F_compound *obj, Boolean merge, int xoff, int yoff, fig_set
 	for (i=0; i<MAXCOMMENTS; i++)
 	    comments[i] = (char *) NULL;
     com_alloc = True;
-    bzero((char*)obj, COMOBJ_SIZE);
+    memset(obj, 0, COMOBJ_SIZE);
     line_no = 1;
     /* read the version header line (e.g. #FIG 3.2) */
     if (fgets(buf, BUF_SIZE, fp) == 0)
@@ -359,7 +377,7 @@ readfp_fig(FILE *fp, F_compound *obj, Boolean merge, int xoff, int yoff, fig_set
 	file_msg("Seeing if this figure is Fig format 1.3");
 	file_msg("If this doesn't work then this is not a Fig file.");
 	proto = 13;
-	status = read_1_3_objects(fp, buf, obj);
+	status = read_1_3_objects(fp, buf, obj, &resolution);
     }
     /* don't go any further if there was an error in reading the figure */
     if (status != 0) {
@@ -367,7 +385,7 @@ readfp_fig(FILE *fp, F_compound *obj, Boolean merge, int xoff, int yoff, fig_set
     }
 
     n_num_usr_cols++;	/* number of user colors = max index + 1 */
-    /*******************************************************************************
+    /***************************************************************************
 	The older versions of xfig (1.3 to 2.1) used values that ended in 4 or 9
 	for coordinates on the "grid".  When multiplied by 15 for the 3.0
 	resolution these values ended up 14 "new" pixels off the grid.
@@ -375,10 +393,14 @@ readfp_fig(FILE *fp, F_compound *obj, Boolean merge, int xoff, int yoff, fig_set
 	For 3.0 files, 1 is added to the coordinates, and in addition, the USER
 	is supposed to set the x and y offset in the file panel both to the
 	amount necessary to correct the problem.
-	For older files 1 is first added to coordinates then they are multiplied by 15.
-    ********************************************************************************/
+	For older files 1 is first added to coordinates then they are multiplied
+	by 15.
+    ***************************************************************************/
+    /* See also doc/FORMAT3.0 */
 
-    if (proto == 30) {
+    /* I do not see, where 1 is first added. */
+    if (proto == 30 || proto == 13) {
+	    /* Fig 1.3 objects seem to lie on "nice" coordinates. */
        scale_figure(obj,((float)PIX_PER_INCH)/resolution,0);
     } else if (resolution != PIX_PER_INCH) {
        if (proto == 21 && resolution == 76 && !settings->units)
@@ -404,32 +426,35 @@ readfp_fig(FILE *fp, F_compound *obj, Boolean merge, int xoff, int yoff, fig_set
     /* get bounding box of whole figure */
     compound_bound(obj,&obj->nwcorner.x,&obj->nwcorner.y,&obj->secorner.x,&obj->secorner.y);
 
-    /* ask the user if the figure should be shifted if there are negative coords */
-    if (!update_figs)
+    /* ask the user if the figure should be shifted
+       if there are negative coords */
+    if (!update_figs) {
 	shift_figure(obj);
 
-    /* now update the grid/ruler units */
-    if (settings->units) {
-	/* inches */
-	if (strcasecmp(appres.tgrid_unit, "default") != 0) {
-	    /* the user specified a units when he started, try to keep it */
-	    if (strcasecmp(appres.tgrid_unit, "tenth") == 0 ||
-		strcasecmp(appres.tgrid_unit, "ten") == 0 ||
-		strcasecmp(appres.tgrid_unit, "1/10") == 0 ||
-		strcasecmp(appres.tgrid_unit, "10") == 0)
+	/* now update the grid/ruler units */
+	if (settings->units) {
+	    /* inches */
+	    if (strcasecmp(appres.tgrid_unit, "default") != 0) {
+		/* the user specified a units when he started, try to keep it */
+		if (strcasecmp(appres.tgrid_unit, "tenth") == 0 ||
+			strcasecmp(appres.tgrid_unit, "ten") == 0 ||
+			strcasecmp(appres.tgrid_unit, "1/10") == 0 ||
+			strcasecmp(appres.tgrid_unit, "10") == 0)
 		    settings->grid_unit = TENTH_UNIT;
 		else
 		    settings->grid_unit = FRACT_UNIT;
+	    } else {
+		settings->grid_unit = FRACT_UNIT;
+	    }
 	} else {
-	    settings->grid_unit = FRACT_UNIT;
+	    /* metric, only choice */
+	    settings->grid_unit = MM_UNIT;
 	}
-    } else {
-	/* metric, only choice */
-	settings->grid_unit = MM_UNIT;
-    }
+    } /* !update_figs */
+
     /* return with status */
     return read_return(status);
-}
+    }
 
 /* clear defer_update_layers counter, update the layer buttons and return status */
 
@@ -442,7 +467,8 @@ read_return(int status)
     return status;
 }
 
-int read_objects(FILE *fp, F_compound *obj, int *res)
+static int
+read_objects(FILE *fp, F_compound *obj, int *res)
 {
     F_ellipse	   *e, *le = NULL;
     F_line	   *l, *ll = NULL;
@@ -482,7 +508,7 @@ int read_objects(FILE *fp, F_compound *obj, int *res)
 	}
 	switch (object) {
 	case O_COLOR_DEF:
-	    read_colordef(fp);
+	    read_colordef();
 	    if (num_object) {
 		file_msg("Color definitions must come before other objects (line %d).",
 			line_no);
@@ -555,7 +581,8 @@ int read_objects(FILE *fp, F_compound *obj, int *res)
 	return errno;
 }				/* read_objects */
 
-int parse_papersize(char *size)
+int
+parse_papersize(char *size)
 {
     int i,len;
     char *c;
@@ -582,7 +609,7 @@ int parse_papersize(char *size)
 }
 
 static void
-read_colordef(FILE *fp)
+read_colordef(void)
 {
     int		    c,r,g,b;
 
@@ -1506,7 +1533,7 @@ read_textobject(FILE *fp)
 }
 
 /* akm 28/2/95 - count consecutive backslashes backwards */
-int
+static int
 backslash_count(char *cp, int start)
 {
   int i, count = 0;
@@ -1553,7 +1580,8 @@ attach_comments(void)
     return comp;
 }
 
-int read_line(FILE *fp)
+static int
+read_line(FILE *fp)
 {
     while (1) {
 	if (NULL == fgets(buf, BUF_SIZE, fp)) {
@@ -1561,7 +1589,7 @@ int read_line(FILE *fp)
 	}
 	line_no++;
 	if (*buf == '#') {		/* save any comments */
-	    if (save_comment(fp) < 0)
+	    if (save_comment() < 0)
 		return -1;
 	} else if (*buf != '\n')	/* Skip empty lines */
 	    return 1;
@@ -1570,30 +1598,36 @@ int read_line(FILE *fp)
 
 /* save a comment line to be stored with the *subsequent* object */
 
-int save_comment(FILE *fp)
+static int
+save_comment(void)
 {
-    int		    i;
+	size_t	i;
 
-    i=strlen(buf);
-    /* see if we've allocated space for this comment */
-    if (comments[numcom])
-	free(comments[numcom]);
-    if ((comments[numcom] = (char*) new_string(i+1)) == NULL)
-	    return -1;
-    /* remove any newline */
-    if (buf[i-1] == '\n')
-	buf[i-1] = '\0';
-    i=1;
-    if (buf[1] == ' ')	/* remove one leading blank from the comment, if there is one */
-	i=2;
-    if (numcom < MAXCOMMENTS)
+	/* skip too many comment lines */
+	if (numcom == MAXCOMMENTS)
+		return 2;
+
+	i = strlen(buf);
+	/* see if we've allocated space for this comment */
+	if (comments[numcom])
+		free(comments[numcom]);
+	if ((comments[numcom] = (char*)new_string(i+1)) == NULL)
+		return -1;
+	/* remove any newline */
+	if (buf[i-1] == '\n')
+		buf[i-1] = '\0';
+	i = 1;
+	if (buf[1] == ' ')
+		/* remove one leading blank from the comment, if there is one */
+		i = 2;
 	strcpy(comments[numcom++], &buf[i]);
-    return 1;
+	return 1;
 }
 
 /* skip to the end of the current line */
 
-void skip_line(FILE *fp)
+static void
+skip_line(FILE *fp)
 {
     while (fgetc(fp) != '\n') {
 	if (feof(fp))
@@ -1603,7 +1637,8 @@ void skip_line(FILE *fp)
 
 /* make sure angle is 0 to 2PI */
 
-void fix_angle(float *angle)
+void
+fix_angle(float *angle)
 {
     while (*angle < 0.0)
 	*angle += M_2PI;
@@ -1611,7 +1646,8 @@ void fix_angle(float *angle)
 	*angle -= M_2PI;
 }
 
-void fix_depth(int *depth)
+static void
+fix_depth(int *depth)
 {
     if (*depth>MAX_DEPTH) {
 	    *depth=MAX_DEPTH;
@@ -1625,9 +1661,9 @@ void fix_depth(int *depth)
 	}
 }
 
-char shift_msg[] = "The figure has objects which have negative coordinates,\ndo you wish to shift it back on the page?";
 
-void shift_figure(F_compound *obj)
+static void
+shift_figure(F_compound *obj)
 {
     F_ellipse	   *e;
     F_arc	   *a;
@@ -1637,6 +1673,7 @@ void shift_figure(F_compound *obj)
     F_text	   *t;
     int		    lowx,lowy,dx,dy;
     int		    rnd;
+    char shift_msg[] = "The figure has objects which have negative coordinates,\ndo you wish to shift it back on the page?";
 
     /* if user is allowing negative coords, return */
     if (appres.allownegcoords)
@@ -1655,7 +1692,7 @@ void shift_figure(F_compound *obj)
 
     /* shift the whole figure to keep it "on the page" */
     dx = dy = 0;
-    rnd = posn_rnd[cur_gridunit][cur_pointposn];
+    rnd = point_spacing();
     if (lowx < 0) {
 	dx = -lowx+rnd;	/* and round up to small grid */
     }
@@ -1679,7 +1716,8 @@ void shift_figure(F_compound *obj)
 	translate_text(t, dx, dy);
 }
 
-void scale_figure(F_compound *obj, float mul, int offset)
+static void
+scale_figure(F_compound *obj, float mul, int offset)
 {
     /* scale the whole figure for new pixels per inch */
     if (mul != 1.0)
@@ -1696,7 +1734,8 @@ void scale_figure(F_compound *obj, float mul, int offset)
 
 /* check if user color <color> is defined */
 
-void check_color(int *color)
+void
+check_color(int *color)
 {
     if (*color < NUM_STD_COLS)
 	return;
@@ -1776,7 +1815,8 @@ void swap_colors(void)
 
 static int    renum[MAX_USR_COLS];
 
-void merge_colors(F_compound *objects)
+static void
+merge_colors(F_compound *objects)
 {
     Boolean	    found_exist;
     int		    i,j,newval;
@@ -1859,7 +1899,8 @@ void merge_colors(F_compound *objects)
     num_usr_cols = n_num_usr_cols;
 }
 
-void renumber_comp(F_compound *compound)
+static void
+renumber_comp(F_compound *compound)
 {
 	F_arc	   *a;
 	F_text	   *t;
@@ -1894,7 +1935,8 @@ void renumber_comp(F_compound *compound)
 	}
 }
 
-void renumber(int *color)
+static void
+renumber(int *color)
 {
     if (*color < NUM_STD_COLS)
 	return;
@@ -1931,7 +1973,8 @@ count_lines_correctly(FILE *fp)
 /* make sure arrow style value is legal and convert arrow width and height to
  * same units as thickness in V4.0 and later we will save the values in these units */
 
-void convert_arrow(int *type, float *wd, float *ht)
+static void
+convert_arrow(int *type, float *wd, float *ht)
 {
     if (*type >= NUM_ARROW_TYPES/2)
 	*type = 0;
