@@ -3,7 +3,7 @@
  * Copyright (c) 1985-1988 by Supoj Sutanthavibul
  * Parts Copyright (c) 1989-2015 by Brian V. Smith
  * Parts Copyright (c) 1991 by Paul King
- * Parts Copyright (c) 2016-2019 by Thomas Loimer
+ * Parts Copyright (c) 2016-2021 by Thomas Loimer
  *
  * Any party obtaining a copy of these files is granted, free of charge, a
  * full and unrestricted irrevocable, world-wide, paid up, royalty-free,
@@ -16,80 +16,101 @@
  *
  */
 
-#include "fig.h"
-#include "figx.h"
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+#include "main.h"
+
+#include <errno.h>
+#include <limits.h>
+#include <locale.h>
+#include <signal.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+#include <unistd.h>
+#include <sys/types.h>
+
+#include <X11/IntrinsicP.h>
+#include <X11/CoreP.h>		/* requires X11/IntrinsicP.h */
+#include <X11/Shell.h>
+#include <X11/StringDefs.h>
+#include <X11/Xlib.h>
+#include <X11/Xresource.h>
+#include <X11/Xutil.h>
+#include <X11/xpm.h>
+#ifdef I18N
+#include <X11/keysym.h>
+#endif
+#ifdef USE_TAB		/* input extensions for an input tablet */
+#include <X11/extensions/XInput.h>
+#endif
+#ifdef XAW3D
+#include <X11/Xaw3d/Form.h>
+#include <X11/Xaw3d/Label.h>
+#else
+#include <X11/Xaw/Form.h>
+#include <X11/Xaw/Label.h>
+#endif /* XAW3D */
+
 #include "resources.h"
 #include "object.h"
-#include "main.h"
 #include "mode.h"
 #include "d_text.h"
 #include "e_edit.h"
+#include "f_load.h"
 #include "f_read.h"
 #include "f_util.h"
 #include "u_error.h"
-#include "u_fonts.h"
 #include "u_redraw.h"
 #include "u_undo.h"
 #include "w_canvas.h"
-#include "w_indpanel.h"
+#include "w_cmdpanel.h"
 #include "w_color.h"
 #include "w_cursor.h"
-#include "w_cmdpanel.h"
 #include "w_digitize.h"
 #include "w_drawprim.h"
+#include "w_export.h"
 #include "w_file.h"
 #include "w_fontpanel.h"
-#include "w_export.h"
 #include "w_help.h"
 #include "w_icons.h"
 #include "w_indpanel.h"
 #include "w_layers.h"
 #include "w_library.h"
-#include "w_msgpanel.h"
 #include "w_modepanel.h"
 #include "w_mousefun.h"
+#include "w_msgpanel.h"
 #include "w_print.h"
 #include "w_rulers.h"
-#include "w_srchrepl.h"
 #include "w_setup.h"
+#include "w_snap.h"
+#include "w_srchrepl.h"
 #include "w_style.h"
 #include "w_util.h"
 #include "w_zoom.h"
-#include "w_snap.h"
-#include "f_load.h"
+#include "xfig_math.h"
 
-/* input extensions for an input tablet */
-#ifdef USE_TAB
-#include "X11/extensions/XInput.h"
-#endif /* USE_TAB */
-
-#ifdef I18N
-#include <X11/keysym.h>
-#endif  /* I18N */
-
-#include <X11/IntrinsicP.h>
 
 /* EXPORTS */
 
-Boolean	    geomspec;
+Boolean	geomspec;
+char	*arg_filename = NULL;
+Atom	wm_protocols[2];
+int	xargc;		/* keeps copies of the command-line arguments */
+char	**xargv;
 
 /* LOCALS */
 
-int		update_fig_files();
+static int	cnt;
 static int	screen_res;
-static void	make_cut_buf_name(void);
-static void	check_resource_ranges(void);
-static void	set_icon_geom(void);
-static void	set_max_image_colors(void);
-static void	parse_canvas_colors(void);
-static void	set_xpm_icon(void);
-static void	resize_canvas(void);
-static void check_refresh(XtPointer client_data, XtIntervalId *id);
-
-/************** FIG options ******************/
+static int	xpm_icon_status; /* status from reading the xpm icon */
+static Arg	args[10];
 
 DeclareStaticArgs(10);
-char    *arg_filename = NULL;
 
 static Boolean	true = True;
 static Boolean	false = False;
@@ -99,6 +120,22 @@ static float	F100 = 100.0;
 static float	FDef_arrow_wd = DEF_ARROW_WID;
 static float	FDef_arrow_ht = DEF_ARROW_HT;
 
+static String	tool_translations =
+			"<Message>WM_PROTOCOLS:Quit()\n";
+static String	form_translations =
+			"<ConfigureNotify>:ResizeForm()\n";
+
+typedef struct
+{
+	Visual	*visual;
+	int	depth;
+} OptionsRec;
+static OptionsRec	Options;
+
+static struct geom {
+	int wid, ht;
+} geom;
+
 /* actions so that we may install accelerators at the top level */
 static XtActionsRec	main_actions[] =
 {
@@ -131,10 +168,22 @@ static XtActionsRec	main_actions[] =
     {"SpinnerUpDown",	(XtActionProc) spinner_up_down},
 };
 
+static XtActionsRec	form_actions[] =
+{
+    {"ResizeForm", (XtActionProc) check_for_resize},
+    {"Quit", (XtActionProc) my_quit},
+};
+
+static XtActionsRec text_panel_actions[] =
+{
+    {"PastePanelKey", (XtActionProc) paste_panel_key} ,
+    {"EmptyTextKey", (XtActionProc) clear_text_key} ,
+};
+
 static XtResource application_resources[] = {
+	/* {name, class, type, size, offset, default type, &(default value)} */
     {"geometry",  "XtCGeometry",    XtRString,  sizeof(char *),
       XtOffset(appresPtr, geometry), XtRString, (caddr_t) NULL},
-
     {"version",  "version",    XtRString,  sizeof(char *),
       XtOffset(appresPtr,version), XtRString, (caddr_t) NULL},
     {"zoom", "Zoom", XtRFloat, sizeof(float),
@@ -298,7 +347,7 @@ static XtResource application_resources[] = {
     {"freehand_resolution", "Hints",   XtRInt, sizeof(int),
       XtOffset(appresPtr, freehand_resolution), XtRImmediate, (caddr_t) 25},
     {"ghostscript", "Ghostscript",   XtRString, sizeof(char *),
-      XtOffset(appresPtr, ghostscript), XtRString, (caddr_t) "gs"},
+      XtOffset(appresPtr, ghostscript), XtRString, (caddr_t) GSEXE},
     {"correct_font_size", "Size",   XtRBoolean, sizeof(Boolean),
       XtOffset(appresPtr, correct_font_size), XtRBoolean, (caddr_t) & true},
     {"encoding", "Encoding", XtRInt, sizeof(int),
@@ -344,9 +393,10 @@ static XtResource application_resources[] = {
 #endif  /* I18N */
 };
 
-/* BE SURE TO UPDATE THE -help COMMAND OPTION LIST IF ANY CHANGES ARE MADE HERE */
-
-XrmOptionDescRec options[] =
+/*
+ * BE SURE TO UPDATE THE -help COMMAND OPTION LIST IF ANY CHANGES ARE MADE HERE
+ */
+static XrmOptionDescRec options[] =
 {
     {"-visual", "*visual", XrmoptionSepArg, NULL},
     {"-depth", "*depth", XrmoptionSepArg, NULL},
@@ -378,7 +428,7 @@ XrmOptionDescRec options[] =
     {"-noflipvisualhints", ".flipvisualhints", XrmoptionNoArg, "False"},
     {"-flushleft", ".flushleft", XrmoptionNoArg, "True"},
     {"-freehand_resolution", ".freehand_resolution", XrmoptionSepArg, 0},
-    {"-ghostscript", ".ghostscript", XrmoptionSepArg, "gs"},
+    {"-ghostscript", ".ghostscript", XrmoptionSepArg, GSEXE},
     {"-grid_color", ".grid_color", XrmoptionSepArg, "lightblue"},
     {"-grid_unit", ".grid_unit", XrmoptionSepArg, "default"},
     {"-hiddentext", ".hiddentext", XrmoptionNoArg, "True"},
@@ -466,7 +516,7 @@ XrmOptionDescRec options[] =
 #endif  /* I18N */
 };
 
-char *help_list[] = {
+static char *help_list[] = {
 	"[-allownegcoords] ",
 	"[-autorefresh] ",
 	"[-axislines <color>] ",
@@ -498,6 +548,7 @@ char *help_list[] = {
 	"[-ghostscript <gsname>] ",
 	"[-grid_color <grid_color>] ",
 	"[-grid_unit <grid_unit>] ",
+	"[-gslib <gslibrary name>] ",
 	"[-hiddentext] ",
 	"[-dontshowdepthmanager] ",
 	"[-iconGeometry <geom>] ",
@@ -576,44 +627,7 @@ char *help_list[] = {
 	"  [file] ",
 	NULL } ;
 
-Atom wm_protocols[2];
-
-static String	tool_translations =
-			"<Message>WM_PROTOCOLS:Quit()\n";
-static String	form_translations =
-			"<ConfigureNotify>:ResizeForm()\n";
-XtActionsRec	form_actions[] =
-{
-    {"ResizeForm", (XtActionProc) check_for_resize},
-    {"Quit", (XtActionProc) my_quit},
-};
-
-static XtActionsRec text_panel_actions[] =
-{
-    {"PastePanelKey", (XtActionProc) paste_panel_key} ,
-    {"EmptyTextKey", (XtActionProc) clear_text_key} ,
-};
-
-struct geom {
-	int wid,ht;
-	};
-
-#define NCHILDREN	9
-
-static Arg	    args[10];
-static int	    cnt;
-
-/* to get any visual the user specifies */
-
-typedef struct
-{
-	Visual	*visual;
-	int	depth;
-} OptionsRec;
-
-OptionsRec	Options;
-
-XtResource resources[] =
+static XtResource resources[] =
 {
 	{"visual", "Visual", XtRVisual, sizeof (Visual *),
 	XtOffsetOf (OptionsRec, visual), XtRImmediate, NULL},
@@ -621,20 +635,22 @@ XtResource resources[] =
 	XtOffsetOf (OptionsRec, depth), XtRImmediate, NULL},
 };
 
-XtTimerCallbackProc manage_layer_buttons();
+static void	make_cut_buf_name(void);
+static void	check_resource_ranges(void);
+static void	set_icon_geom(void);
+static void	set_max_image_colors(void);
+static void	parse_canvas_colors(void);
+static void	set_xpm_icon(void);
+static void	resize_canvas(void);
+static void	check_refresh(XtPointer client_data, XtIntervalId *id);
+static int	setup_visual (int *argc_p, char **argv, Arg *args);
+static void	get_pointer_mapping (void);
 
-int	xargc;		/* keeps copies of the command-line arguments */
-char  **xargv;
-int	xpm_icon_status; /* status from reading the xpm icon */
-struct  geom   geom;
-
-
-int setup_visual (int *argc_p, char **argv, Arg *args);
-void get_pointer_mapping (void);
 
 int
 main(int argc, char **argv)
 {
+#define NCHILDREN	9
     Widget	    children[NCHILDREN];
     XEvent	    event;
     int		    ichild;
@@ -660,10 +676,24 @@ main(int argc, char **argv)
     update_figs = False;
 
     /* get the TMPDIR environment variable for temporary files */
-    if ((TMPDIR = getenv("XFIGTMPDIR"))==NULL) {
-		if ((TMPDIR = getenv("TMPDIR")) == NULL)
-			TMPDIR = "/tmp";
+    if (((TMPDIR = getenv("XFIGTMPDIR")) && !access(TMPDIR, W_OK | X_OK)) ||
+		((TMPDIR = getenv("TMPDIR")) && !access(TMPDIR, W_OK | X_OK))) {
+	if (strchr(TMPDIR, '\'')) {
+		fprintf(stderr, "Cannot use a temporary directory with an "
+			"apostrophe (') in its name: %s.\nPlease set the "
+			"environment variables XFIGTMPDIR or TMPDIR to a\n"
+			"different location.\n", TMPDIR);
+		exit(-1);
 	}
+    } else {
+	TMPDIR = P_tmpdir;
+	/* if this is not writable and accessible, fail later, at a time
+	   when a temporary file is needed. */
+    }
+
+    /* ratio of Fig units to display resolution (80ppi) */
+    /* might also be needed when updating a figure */
+    ZOOM_FACTOR = PIX_PER_INCH/DISPLAY_PIX_PER_INCH;
 
     /* first check args to see if user wants to scale the figure as it is
 	read in and make sure it is a resonable (positive) number */
@@ -680,7 +710,13 @@ main(int argc, char **argv)
 	/* see if user just wants to update Fig files to current version */
 	/*****************************************************************/
 
-	/* yes, go do it and exit */
+	update_figs = True;
+
+	/* if the fig file contains text objects,
+	   update_fig_files() depends on font information */
+	cnt = setup_visual(&argc, argv, args);
+	init_font();
+
 	exit(update_fig_files(argc,argv));
 
     } else if (argc > 1) {
@@ -765,7 +801,7 @@ main(int argc, char **argv)
 
     xargc = argc;
     xargv = (char **) XtMalloc ((argc+1) * sizeof (char *));
-    bcopy ((char *) argv, (char *) xargv, argc * sizeof (char *));
+    memcpy(xargv, argv, argc * sizeof(char *));
 
     /* for some reason Solaris version of XtAppCreateShell references the following */
     xargv[argc]=NULL;
@@ -787,9 +823,6 @@ main(int argc, char **argv)
     screen_wd = WidthOfScreen(XtScreen(tool));
     screen_ht = HeightOfScreen(XtScreen(tool));
 
-    /* ratio of Fig units to display resolution (80ppi) */
-    ZOOM_FACTOR = PIX_PER_INCH/DISPLAY_PIX_PER_INCH;
-
     /* get the FIG2DEV_DIR environment variable (if any is set) for the path
        to fig2dev, in case the user wants one not in the normal search path */
     if ((fig2dev_path = getenv("FIG2DEV_DIR"))==NULL)
@@ -1251,12 +1284,12 @@ main(int argc, char **argv)
 	strcpy(cur_filename, arg_filename);
 
     /* save path if specified in filename */
-    if (dval=strrchr(cur_filename, '/')) {
+    if ((dval = strrchr(cur_filename, '/'))) {
+	size_t	len = dval - cur_filename;
 	strcpy(cur_file_dir, cur_filename);
+	cur_file_dir[len] = '\0';
 	/* remove path from filename */
-	strcpy(cur_filename, dval+1);
-	if (dval=strrchr(cur_file_dir, '/'))
-	    *dval = '\0';  /* terminate path at the last "/" */
+	strcpy(cur_filename, cur_file_dir + len + 1);
 	change_directory(cur_file_dir);		/* go there */
 	/* and get back the canonical (absolute) path */
 	get_directory(cur_file_dir);
@@ -1568,7 +1601,7 @@ notablet:
 
 /* setup all the visual and depth stuff */
 
-int
+static int
 setup_visual(int *argc_p, char **argv, Arg *args)
 {
 	int	       i, n, cnt;
@@ -1931,7 +1964,8 @@ resize_canvas(void)
 
 /* flip the mouse hints if the pointer mapping is reversed */
 
-void get_pointer_mapping(void)
+static void
+get_pointer_mapping(void)
 {
 	unsigned char mapping[3];
 	int	      nmap;
