@@ -1,8 +1,9 @@
 /*
  * FIG : Facility for Interactive Generation of figures
  * Copyright (c) 1985-1988 by Supoj Sutanthavibul
- * Parts Copyright (c) 1989-2007 by Brian V. Smith
+ * Parts Copyright (c) 1989-2015 by Brian V. Smith
  * Parts Copyright (c) 1991 by Paul King
+ * Parts Copyright (c) 2016-2020 by Thomas Loimer
  *
  * Any party obtaining a copy of these files is granted, free of charge, a
  * full and unrestricted irrevocable, world-wide, paid up, royalty-free,
@@ -18,8 +19,18 @@
 #ifndef RESOURCES_H
 #define RESOURCES_H
 
-#include "paintop.h"
+#if defined HAVE_CONFIG_H && !defined VERSION
+#include "config.h"
+#endif
+
 #include <limits.h>		/* PATH_MAX, below */
+#include <sys/types.h>
+#include <X11/Intrinsic.h>
+#ifdef USE_XPM
+#include <X11/xpm.h>
+#endif
+#include "paintop.h"
+
 #ifndef PATH_MAX
 #define PATH_MAX	1024
 #endif
@@ -96,7 +107,7 @@
 #define DEF_RECENT_FILES	5
 
 /* for picture files */
-#define	MAX_COLORMAP_SIZE	MAX_USR_COLS
+#define	MAX_COLORMAP_SIZE	256
 
 /* for JPEG export */
 #define	DEF_JPEG_QUALITY	75
@@ -141,7 +152,6 @@ extern char		 orig_dir[PATH_MAX+2];
 extern Boolean		 update_figs;
 
 #ifdef USE_XPM
-#include <X11/xpm.h>
 extern XpmAttributes	 xfig_icon_attr;
 #endif
 extern fig_colors	 colorNames[NUM_STD_COLS + 1];
@@ -265,6 +275,7 @@ typedef struct _appres {
     char	*tgrid_unit;		/* units of grid/point positioning (1/10" or 1/16") */
     Boolean	 overlap;		/* overlap/no-overlap multiple pages for export/print */
     char	*ghostscript;		/* name of ghostscript (e.g. gs or gswin32) */
+    char	*gslib;			/* name of ghostscript library */
     Boolean	 correct_font_size;	/* adjust for difference in Fig screen res vs points (80/72) */
     int		 encoding;		/* encoding for latex escape translation */
     Boolean	save8bit;		/* save 8bit files */
