@@ -9,7 +9,7 @@
  * full and unrestricted irrevocable, world-wide, paid up, royalty-free,
  * nonexclusive right and license to deal in this software and documentation
  * files (the "Software"), including without limitation the rights to use,
- * copy, modify, merge, publish distribute, sublicense and/or sell copies of
+ * copy, modify, merge, publish, distribute, sublicense and/or sell copies of
  * the Software, and to permit persons who receive copies from any such
  * party to do so, with the only requirement being that the above copyright
  * and this permission notice remain intact.
@@ -374,7 +374,7 @@ print_to_file(char *file, int xoff, int yoff, char *backgrnd, char *transparent,
 			/* make it suitable for pstex. */
 			strcpy(tmpcmd, prcmd);
 			strcat(tmpcmd, ".eps");
-			(void) exec_prcmd(tmpcmd, "EXPORT of PostScript part");
+			(void) exec_prcmd(tmpcmd, "EXPORT of EPS part");
 
 			/* make it suitable for pdftex. */
 			strsub(prcmd, "ps", "pdf", tmpcmd, 0);
@@ -483,8 +483,11 @@ print_to_file(char *file, int xoff, int yoff, char *backgrnd, char *transparent,
 
 	} else if (cur_exp_lang == LANG_PCX || cur_exp_lang == LANG_PNG ||
 			cur_exp_lang == LANG_TIFF || cur_exp_lang == LANG_XBM ||
-			cur_exp_lang == LANG_XPM || cur_exp_lang == LANG_PPM ||
-			cur_exp_lang == LANG_JPEG || cur_exp_lang == LANG_GIF) {
+#ifdef USE_XPM
+			cur_exp_lang == LANG_XPM ||
+#endif
+			cur_exp_lang == LANG_PPM || cur_exp_lang == LANG_JPEG ||
+			cur_exp_lang == LANG_GIF) {
 
 		/* GIF must come before giving background option */
 		if (cur_exp_lang == LANG_GIF) {
@@ -693,7 +696,7 @@ build_layer_list(char *layers)
 {
 	char	list[PATH_MAX], notlist[PATH_MAX], num[10];
 	int	layer, len, notlen;
-	int	firstyes, lastyes, firstno, lastno;
+	int	firstyes, lastyes = 0, firstno, lastno = 0;
 
 	layers[0] = '\0';
 
