@@ -1,8 +1,9 @@
 /*
  * FIG : Facility for Interactive Generation of figures
  * Copyright (c) 1985-1988 by Supoj Sutanthavibul
- * Parts Copyright (c) 1989-2007 by Brian V. Smith
+ * Parts Copyright (c) 1989-2015 by Brian V. Smith
  * Parts Copyright (c) 1991 by Paul King
+ * Parts Copyright (c) 2016-2020 by Thomas Loimer
  *
  * Any party obtaining a copy of these files is granted, free of charge, a
  * full and unrestricted irrevocable, world-wide, paid up, royalty-free,
@@ -18,7 +19,8 @@
 #ifndef W_CANVAS_H
 #define W_CANVAS_H
 
-/************** DECLARE EXPORTS ***************/
+#include <X11/Intrinsic.h>	/* String, Widget, Cardinal */
+#include <X11/Xlib.h>		/* XButtonEvent */
 
 extern void	init_canvas(Widget tool);
 extern void	add_canvas_actions(void);
@@ -38,11 +40,12 @@ extern void	toggle_show_borders(void);
 extern void	round_coords(int *x, int *y);		// isometric grid
 extern int	point_spacing(void);
 
-extern void		canvas_selected(Widget tool, XButtonEvent *event, String *params, Cardinal *nparams);
+extern void	canvas_selected(Widget tool, XButtonEvent *event,
+				String *params, Cardinal *nparams);
 extern void	paste_primary_selection(void);
-extern void setup_canvas(void);
-extern void clear_region(int xmin, int ymin, int xmax, int ymax);
-extern void clear_canvas(void);
+extern void	setup_canvas(void);
+extern void	clear_region(int xmin, int ymin, int xmax, int ymax);
+extern void	clear_canvas(void);
 
 extern int	clip_xmin, clip_ymin, clip_xmax, clip_ymax;
 extern int	clip_width, clip_height;
