@@ -1,13 +1,15 @@
 /*
  * FIG : Facility for Interactive Generation of figures
- * Copyright (c) 1989-2007 by Brian V. Smith
+ * Copyright (c) 1985-1988 by Supoj Sutanthavibul
+ * Parts Copyright (c) 1989-2015 by Brian V. Smith
  * Parts Copyright (c) 1991 by Paul King
+ * Parts Copyright (c) 2016-2021 by Thomas Loimer
  *
  * Any party obtaining a copy of these files is granted, free of charge, a
  * full and unrestricted irrevocable, world-wide, paid up, royalty-free,
  * nonexclusive right and license to deal in this software and documentation
  * files (the "Software"), including without limitation the rights to use,
- * copy, modify, merge, publish distribute, sublicense and/or sell copies of
+ * copy, modify, merge, publish, distribute, sublicense and/or sell copies of
  * the Software, and to permit persons who receive copies from any such
  * party to do so, with the only requirement being that the above copyright
  * and this permission notice remain intact.
@@ -515,10 +517,13 @@ do_save(Widget w, XButtonEvent *ev)
 	}
     } else { /* !file_popup */
 	/*
-	 * !file_popup, so the file panel was never created and the user
-	 * never had the possibility to change directory.
-	 * Also, save_file_dir = "" (I believe)
+	 * !file_popup, so the file panel was never created and probably
+	 * save_file_dir not set.
 	 */
+	if (*save_file_dir == '\0') {
+		strcpy(save_file_dir, cur_file_dir);
+		change_directory(save_file_dir);
+	}
 	/* see if writable */
 	if (!ok_to_write(cur_filename, "SAVE"))
 	    return;
