@@ -9,7 +9,7 @@
  * full and unrestricted irrevocable, world-wide, paid up, royalty-free,
  * nonexclusive right and license to deal in this software and documentation
  * files (the "Software"), including without limitation the rights to use,
- * copy, modify, merge, publish distribute, sublicense and/or sell copies of
+ * copy, modify, merge, publish, distribute, sublicense and/or sell copies of
  * the Software, and to permit persons who receive copies from any such
  * party to do so, with the only requirement being that the above copyright
  * and this permission notice remain intact.
@@ -362,7 +362,7 @@ handle_keyboard_input(w, event)
     if (True == keyboard_input_available) {
       if (NULL == keyboard_history) {
 	keyboard_history = malloc(KEYBOARD_HISTORY_MAX * sizeof(keyboard_history_s));
-	bzero(keyboard_history, KEYBOARD_HISTORY_MAX * sizeof(keyboard_history_s));
+	memset(keyboard_history, 0, KEYBOARD_HISTORY_MAX*sizeof(keyboard_history_s));
 	keyboard_history_nr_etys = 1;
 	keyboard_history_read_pointer = keyboard_history_write_pointer = &keyboard_history[0];
 	keyboard_history[0].next  = keyboard_history_read_pointer;
