@@ -1,14 +1,15 @@
 /*
  * FIG : Facility for Interactive Generation of figures
  * Copyright (c) 1985-1988 by Supoj Sutanthavibul
- * Parts Copyright (c) 1989-2007 by Brian V. Smith
+ * Parts Copyright (c) 1989-2015 by Brian V. Smith
  * Parts Copyright (c) 1991 by Paul King
+ * Parts Copyright (c) 2016-2021 by Thomas Loimer
  *
  * Any party obtaining a copy of these files is granted, free of charge, a
  * full and unrestricted irrevocable, world-wide, paid up, royalty-free,
  * nonexclusive right and license to deal in this software and documentation
  * files (the "Software"), including without limitation the rights to use,
- * copy, modify, merge, publish distribute, sublicense and/or sell copies of
+ * copy, modify, merge, publish, distribute, sublicense and/or sell copies of
  * the Software, and to permit persons who receive copies from any such
  * party to do so, with the only requirement being that the above copyright
  * and this permission notice remain intact.
@@ -569,7 +570,6 @@ areameas_msg(char *msgtext, float area, float totarea, int flag)
 void
 file_msg(char *format,...)
 {
-    XawTextBlock block;
     va_list ap;
 
     if (!update_figs) {
@@ -590,6 +590,8 @@ file_msg(char *format,...)
     if (update_figs) {
        fprintf(stderr, "%s", tmpstr);
     } else {
+	XawTextBlock block;
+
 	/* append this message to the file message widget string */
 	block.firstPos = 0;
 	block.ptr = tmpstr;
@@ -599,8 +601,9 @@ file_msg(char *format,...)
 	FirstArg(XtNeditType, XawtextEdit);
 	SetValues(file_msg_win);
 	/* insert the new message after the end */
-	(void) XawTextReplace(file_msg_win,file_msg_length,file_msg_length,&block);
-	(void) XawTextSetInsertionPoint(file_msg_win,file_msg_length);
+	(void)XawTextReplace(file_msg_win, file_msg_length, file_msg_length,
+		&block);
+	(void)XawTextSetInsertionPoint(file_msg_win, file_msg_length);
 
 	/* make read-only again */
 	FirstArg(XtNeditType, XawtextRead);
